@@ -1,4 +1,8 @@
 //! Ncurses-specific backend.
+#![cfg(feature = "ncurses-backend")]
+#![cfg_attr(feature = "doc-cfg", doc(cfg(feature = "ncurses-backend")))]
+pub use ncurses;
+
 use log::{debug, warn};
 use ncurses::mmask_t;
 
@@ -268,13 +272,9 @@ impl Backend {
                     .or_else(|| {
                         // In legacy mode, some buttons overlap,
                         // so we need to disambiguate.
-                        if mevent.bstate
-                            == ncurses::BUTTON5_DOUBLE_CLICKED as mmask_t
-                        {
-                            Some(MouseEvent::WheelDown)
-                        } else {
-                            None
-                        }
+                        (mevent.bstate
+                            == ncurses::BUTTON5_DOUBLE_CLICKED as mmask_t)
+                            .then(|| MouseEvent::WheelDown)
                     })
                     .map(&make_event)
                     .unwrap_or_else(|| Event::Unknown(vec![]))
@@ -334,6 +334,10 @@ impl backend::Backend for Backend {
         "ncurses"
     }
 
+    fn set_title(&mut self, title: String) {
+        write_to_tty(format!("\x1B]0;{}\x07", title).as_bytes()).unwrap();
+    }
+
     fn screen_size(&self) -> Vec2 {
         let mut x: i32 = 0;
         let mut y: i32 = 0;
@@ -363,6 +367,7 @@ impl backend::Backend for Backend {
         let style = match effect {
             Effect::Reverse => ncurses::A_REVERSE(),
             Effect::Simple => ncurses::A_NORMAL(),
+            Effect::Dim => ncurses::A_DIM(),
             Effect::Bold => ncurses::A_BOLD(),
             Effect::Blink => ncurses::A_BLINK(),
             Effect::Italic => ncurses::A_ITALIC(),
@@ -376,6 +381,7 @@ impl backend::Backend for Backend {
         let style = match effect {
             Effect::Reverse => ncurses::A_REVERSE(),
             Effect::Simple => ncurses::A_NORMAL(),
+            Effect::Dim => ncurses::A_DIM(),
             Effect::Bold => ncurses::A_BOLD(),
             Effect::Blink => ncurses::A_BLINK(),
             Effect::Italic => ncurses::A_ITALIC(),
